<template>
    <div class="app-container">
      <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
        <el-form-item label="项目名称">
          <el-input v-model="queryParams.projectName" placeholder="请输入项目名称" />
        </el-form-item>
        <el-form-item label="专家姓名">
          <el-input v-model="queryParams.name" placeholder="请输入姓名" />
        </el-form-item>
        <el-form-item label="身份证号">
          <el-input v-model="queryParams.idCard" placeholder="请输入身份证号" />
        </el-form-item>
        <el-form-item label="专家领域">
          <el-cascader
              clearable
              v-model="queryParams.domain"
              :options="expertTypes"
              :props="{ expandTrigger: 'hover', value: 'classifyName',label: 'classifyName',emitPath: false}"></el-cascader>
        </el-form-item>
        <el-form-item label="时间范围" prop="searchTime">
          <el-date-picker
              v-model="searchTime"
              type="datetimerange"
              range-separator="至"
              start-placeholder="开始日期"
              end-placeholder="结束日期"
              value-format="YYYY-MM-DD HH:mm:ss"
          />
        </el-form-item>
        <el-form-item>
          <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
          <el-button icon="Refresh" @click="resetQuery">重置</el-button>
        </el-form-item>
      </el-form>

<!--      <el-row :gutter="10" class="mb8">-->
<!--        <el-col :span="1.5">-->
<!--          <el-button type="primary" plain :icon="Plus" @click="openDialog('add',{})">新增</el-button>-->
<!--        </el-col>-->
<!--      </el-row>-->
      <el-table v-loading="loading" :data="expertList" :border="true">
        <el-table-column type="index" width="55" align="center" />
        <el-table-column label="考评时间" align="center" prop="updateTime" />
        <el-table-column label="姓名" align="center" prop="name" />
        <el-table-column label="身份证号" align="center" prop="idCard" />
        <el-table-column label="考评应用领域" align="center" prop="domain" />
        <el-table-column label="项目名称" align="center" prop="projectName" />
        <el-table-column label="是否为专家组组长" align="center" prop="teamLeader">
          <template #default="scope">
            {{scope.row.teamLeader == 1?'是':'否'}}
          </template>
        </el-table-column>
        <el-table-column label="考评分数" align="center" prop="score"/>
        <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            <el-button type="primary" link @click="openDialog('view',scope.row)">查看明细</el-button>
          </template>
        </el-table-column>
      </el-table>
      <pagination
          v-show="total > 0"
          :total="total"
          v-model:page="queryParams.pageNum"
          v-model:limit="queryParams.pageSize"
          @pagination="getList"
      />
      <evaluate-detail ref="evaluateFormRef" @getList="getList"></evaluate-detail>
    </div>
</template>

<script setup>
import {getCurrentInstance, onMounted, onUnmounted, reactive, ref, toRefs} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import EvaluateDetail from "./components/evaluateDetail";
import {delExpert, getExpertsList, getExpertTypes} from "../../../../api/form";
import { Plus } from '@element-plus/icons-vue'
import {getExpertEvaList} from "@/api/backManage/evaluate";

const loading = ref(false);
const data = reactive({
  showSearch: true,
  total: 0,
  expertTypes: [],
  expertList: [],
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    projectName: '',
    name: '',
    idCard: '',
    domain: '',
    startTime: '',
    endTime: ''
  },
  searchTime: []
});

const { showSearch,total, expertTypes,expertList,queryParams,classiFy,searchTime} = toRefs(data);
const evaluateFormRef = ref()
onMounted(()=>{
  getList()
  getTypes()
})

onUnmounted(()=>{

})

const getTypes = async()=> {
  const res = await getExpertTypes()
  if(res.code == 200){
    data.expertTypes = res.data
  }else{
    ElMessage.warning(res.message)
  }
}

const findNodeById = (data,value)=> {
  for (const node of data) {
    if (node.id === value) {
      return node.classifyName;
    }
    if (node.children) {
      const foundNode = findNodeById(node.children, value);
      if (foundNode) {
        return foundNode;
      }
    }
  }
  return null;
}

const handleQuery=()=> {
  data.queryParams.pageNum = 1
  getList()
}

const getList = async () => {
  loading.value = true
  data.queryParams.startTime = data.searchTime[0] || ''
  data.queryParams.endTime = data.searchTime[1] || ''
  const res = await getExpertEvaList(data.queryParams)
  if(res.code == 200){
    data.expertList = res.rows
    data.total = res.total
  }else{
    ElMessage.warning(res.msg)
  }
  loading.value = false;
}

const openDialog = async (type, value) => {
  evaluateFormRef.value.openDialog(type, value)
}

const handleDelete = (val) => {
    ElMessageBox.confirm(
        '确定删除此条数据？',
        '提示',
        {
            confirmButtonText: '确定',
            cancelButtonText: '取消',
            type: 'warning',
        })
        .then( async() => {
            const res = await delExpert(val.id)
            if(res.code == 200){
              ElMessage.success('数据删除成功')
              getList()
            }else{
              ElMessage.warning(res.message)
            }
        })
}
const resetQuery=()=> {
  data.queryParams = {
    pageNum: 1,
    pageSize: 10,
    projectName: '',
    name: '',
    idCard: '',
    domain: '',
    startTime: '',
    endTime: ''
  }
  data.searchTime = []
  handleQuery()
}

</script>
